==> teamapps-application-server-0.2-sources.jar: org/teamapps/model/controlcenter/OrganizationUnitTypeQuery.java <==
package org.teamapps.model.controlcenter;

import org.teamapps.universaldb.pojo.*;
import org.teamapps.universaldb.record.*;
import org.teamapps.universaldb.index.text.*;
import org.teamapps.universaldb.index.translation.*;
import org.teamapps.universaldb.index.bool.*;
import org.teamapps.universaldb.index.file.*;
import org.teamapps.universaldb.index.enumeration.*;
import org.teamapps.universaldb.index.numeric.*;
import org.teamapps.universaldb.index.reference.value.*;
import org.teamapps.universaldb.index.reference.multi.*;
import org.teamapps.universaldb.index.reference.single.*;
import org.teamapps.universaldb.index.binary.*;
import org.teamapps.universaldb.query.*;


import java.util.*;
import java.util.function.Function;


public interface OrganizationUnitTypeQuery extends Query<OrganizationUnitType> {

    static OrganizationUnitTypeQuery create() {
        return new UdbOrganizationUnitTypeQuery();
    }

    OrganizationUnitTypeQuery fullTextFilter(TextFilter textFilter, String... fieldNames);

    OrganizationUnitTypeQuery parseFullTextFilter(String query, String... fieldNames);

	OrganizationUnitTypeQuery metaCreationDate(NumericFilter filter);

	OrganizationUnitTypeQuery orMetaCreationDate(NumericFilter filter);

	OrganizationUnitTypeQuery metaCreatedBy(NumericFilter filter);

	OrganizationUnitTypeQuery orMetaCreatedBy(NumericFilter filter);

	OrganizationUnitTypeQuery metaModificationDate(NumericFilter filter);

	OrganizationUnitTypeQuery orMetaModificationDate(NumericFilter filter);

	OrganizationUnitTypeQuery metaModifiedBy(NumericFilter filter);

	OrganizationUnitTypeQuery orMetaModifiedBy(NumericFilter filter);

	OrganizationUnitTypeQuery metaDeletionDate(NumericFilter filter);

	OrganizationUnitTypeQuery orMetaDeletionDate(NumericFilter filter);

	OrganizationUnitTypeQuery metaDeletedBy(NumericFilter filter);

	OrganizationUnitTypeQuery orMetaDeletedBy(NumericFilter filter);

	OrganizationUnitTypeQuery name(TranslatableTextFilter filter);

	OrganizationUnitTypeQuery orName(TranslatableTextFilter filter);

	OrganizationUnitTypeQuery abbreviation(TranslatableTextFilter filter);

	OrganizationUnitTypeQuery orAbbreviation(TranslatableTextFilter filter);

	OrganizationUnitTypeQuery icon(TextFilter filter);

	OrganizationUnitTypeQuery orIcon(TextFilter filter);

	OrganizationUnitTypeQuery translateOrganizationUnits(BooleanFilter filter);

	OrganizationUnitTypeQuery orTranslateOrganizationUnits(BooleanFilter filter);

	OrganizationUnitTypeQuery allowUserContainer(BooleanFilter filter);

	OrganizationUnitTypeQuery orAllowUserContainer(BooleanFilter filter);

	OrganizationUnitTypeQuery filterDefaultChildType(OrganizationUnitTypeQuery query);

	OrganizationUnitTypeQuery defaultChildType(NumericFilter filter);

	OrganizationUnitTypeQuery orDefaultChildType(NumericFilter filter);

	OrganizationUnitTypeQuery filterPossibleChildrenTypes(OrganizationUnitTypeQuery query);

	OrganizationUnitTypeQuery possibleChildrenTypes(MultiReferenceFilterType type, OrganizationUnitType ... value);

	OrganizationUnitTypeQuery possibleChildrenTypesCount(MultiReferenceFilterType type, int count);

	OrganizationUnitTypeQuery possibleChildrenTypes(MultiReferenceFilter filter);

	OrganizationUnitTypeQuery orPossibleChildrenTypes(MultiReferenceFilter filter);

	OrganizationUnitTypeQuery geoLocationType(EnumFilterType filterType, GeoLocationType ... enums);

	OrganizationUnitTypeQuery orGeoLocationType(EnumFilterType filterType, GeoLocationType ... enums);


    OrganizationUnitTypeQuery andOr(OrganizationUnitTypeQuery... queries);

    OrganizationUnitTypeQuery customFilter(Function<OrganizationUnitType, Boolean> customFilter);

    List<OrganizationUnitType> execute();

    OrganizationUnitType executeExpectSingleton();

    BitSet executeToBitSet();

    List<OrganizationUnitType> execute(String sortFieldName, boolean ascending, String ... path);

    List<OrganizationUnitType> execute(int startIndex, int length, Sorting sorting);

}

==> teamapps-application-server-0.5-sources.jar: org/teamapps/model/controlcenter/OrganizationUnitTypeQuery.java <==
package org.teamapps.model.controlcenter;

import org.teamapps.universaldb.pojo.*;
import org.teamapps.universaldb.record.*;
import org.teamapps.universaldb.index.text.*;
import org.teamapps.universaldb.index.translation.*;
import org.teamapps.universaldb.index.bool.*;
import org.teamapps.universaldb.index.file.*;
import org.teamapps.universaldb.index.enumeration.*;
import org.teamapps.universaldb.index.numeric.*;
import org.teamapps.universaldb.index.reference.value.*;
import org.teamapps.universaldb.index.reference.multi.*;
import org.teamapps.universaldb.index.reference.single.*;
import org.teamapps.universaldb.index.binary.*;
import org.teamapps.universaldb.query.*;


import java.util.*;
import java.util.function.Function;


public interface OrganizationUnitTypeQuery extends Query<OrganizationUnitType> {

    static OrganizationUnitTypeQuery create() {
        return new UdbOrganizationUnitTypeQuery();
    }

    OrganizationUnitTypeQuery fullTextFilter(TextFilter textFilter, String... fieldNames);

    OrganizationUnitTypeQuery parseFullTextFilter(String query, String... fieldNames);

	OrganizationUnitTypeQuery metaCreationDate(NumericFilter filter);

	OrganizationUnitTypeQuery orMetaCreationDate(NumericFilter filter);

	OrganizationUnitTypeQuery metaCreatedBy(NumericFilter filter);

	OrganizationUnitTypeQuery orMetaCreatedBy(NumericFilter filter);

	OrganizationUnitTypeQuery metaModificationDate(NumericFilter filter);

	OrganizationUnitTypeQuery orMetaModificationDate(NumericFilter filter);

	OrganizationUnitTypeQuery metaModifiedBy(NumericFilter filter);

	OrganizationUnitTypeQuery orMetaModifiedBy(NumericFilter filter);

	OrganizationUnitTypeQuery metaDeletionDate(NumericFilter filter);

	OrganizationUnitTypeQuery orMetaDeletionDate(NumericFilter filter);

	OrganizationUnitTypeQuery metaDeletedBy(NumericFilter filter);

	OrganizationUnitTypeQuery orMetaDeletedBy(NumericFilter filter);

	OrganizationUnitTypeQuery name(TranslatableTextFilter filter);

	OrganizationUnitTypeQuery orName(TranslatableTextFilter filter);

	OrganizationUnitTypeQuery abbreviation(TranslatableTextFilter filter);

	OrganizationUnitTypeQuery orAbbreviation(TranslatableTextFilter filter);

	OrganizationUnitTypeQuery icon(TextFilter filter);

	OrganizationUnitTypeQuery orIcon(TextFilter filter);

	OrganizationUnitTypeQuery translateOrganizationUnits(BooleanFilter filter);

	OrganizationUnitTypeQuery orTranslateOrganizationUnits(BooleanFilter filter);

	OrganizationUnitTypeQuery allowUsers(BooleanFilter filter);

	OrganizationUnitTypeQuery orAllowUsers(BooleanFilter filter);

	OrganizationUnitTypeQuery filterDefaultChildType(OrganizationUnitTypeQuery query);

	OrganizationUnitTypeQuery defaultChildType(NumericFilter filter);

	OrganizationUnitTypeQuery orDefaultChildType(NumericFilter filter);

	OrganizationUnitTypeQuery filterPossibleChildrenTypes(OrganizationUnitTypeQuery query);

	OrganizationUnitTypeQuery possibleChildrenTypes(MultiReferenceFilterType type, OrganizationUnitType ... value);

	OrganizationUnitTypeQuery possibleChildrenTypesCount(MultiReferenceFilterType type, int count);

	OrganizationUnitTypeQuery possibleChildrenTypes(MultiReferenceFilter filter);

	OrganizationUnitTypeQuery orPossibleChildrenTypes(MultiReferenceFilter filter);

	OrganizationUnitTypeQuery geoLocationType(EnumFilterType filterType, GeoLocationType ... enums);

	OrganizationUnitTypeQuery orGeoLocationType(EnumFilterType filterType, GeoLocationType ... enums);


    OrganizationUnitTypeQuery andOr(OrganizationUnitTypeQuery... queries);

    OrganizationUnitTypeQuery customFilter(Function<OrganizationUnitType, Boolean> customFilter);

    List<OrganizationUnitType> execute();

    OrganizationUnitType executeExpectSingleton();

    BitSet executeToBitSet();

    List<OrganizationUnitType> execute(String sortFieldName, boolean ascending, String ... path);

    List<OrganizationUnitType> execute(int startIndex, int length, Sorting sorting);

}
